# -*- coding: utf8 -*-
"""
Config
Created on 02/22/2016
@description:	Used for 
@author: 		Wen Gu
@contact: 		emptyset110@gmail.com
"""
VERSION = '0.2.0'

#	路径配置		
#	Path Configuration
PATH_DATA_ROOT = './data/'
PATH_DATA_REALTIME = 'stock_realtime/'
PATH_DATA_L2 = 'stock_l2/'

#	Mongodb连接配置
#	Mongodb Configuration

